import Vue from 'vue'
import Router from 'vue-router'
import Layout from '@/views/layout'
import Home from '@/views/Home.vue'
import sysRouters from './modules/sys'
import baseRouters from './modules/base'
import businessRouters from './modules/business'
import { Message } from 'element-ui'
import NProgress from 'nprogress' // progress bar
import 'nprogress/nprogress.css'  // progress bar style
import { getToken } from '@/utils/auth' // get token from cookie
import store from '../store'

Vue.use(Router)
NProgress.configure({ showSpinner: true }) // NProgress Configuration

var routes = [
  {
    path: '/layout',
    component:Layout,
    children: [
      {
        path: '/home',
        name: 'home',
        component: Home
      },
      ...sysRouters,
      ...baseRouters
    ]
  },
  // 改为动态添加
  // {
  //   path: '/buiness',
  //   component:Layout,
  //   children: [
  //     ...businessRouters
  //   ]
  // },
  {
    path:'/',
    redirect: '/home'
  },
  {
    path: '/login',
    component: () => import('@/views/Login')
  }
];

// Array.prototype.push.apply(routes, caseRouters);
// Array.prototype.push.apply(routes, sysRouters);

var router = new Router({
  routes
})

router.beforeEach((to, from, next) => {
  NProgress.start();
  console.log(`${to.path}`);

  const hasToken = getToken()

  if (hasToken != null) {
    console.log(`loaded=${store.state.user.loaded}`);

    if(!store.state.user.loaded){
      // console.log(businessRouters);
      router.addRoutes([{
          path: '/business',
          component:Layout,
          children: businessRouters
      }]);

      store.commit("user/SET_LOADED",true);

      //动态添加路由后
      next({ ...to, replace: true })
    }
    else{
      if (to.path === '/login') {
        // if is logged in, redirect to the home page
        next({ path: '/home' })
      }
      else {
        next();
      }
    }
  }
  else {
    if (to.path === '/login') {
      next();
    }
    else{
      next(`/login?redirect=${to.path}`);
    }
  }

  //NProgress.done();
});

router.afterEach(() => {
  NProgress.done();
});


export default router;